# FOntCell

FOntCell is a software module in Python for automatic computed fusion of ontologies. The FOntCell module produces a fused ontology in OBO format and a circular representation of the fused ontology in a Directed Acyclic Graph (DAG) in an interactive HTML file.

Prerequisites, User Manual, and Troubleshooting availabel at: https://gitlab.com/JavierCabau/fontcell/
